==> telegram_client-0.5.24.tar.gz: lib/telegram_client/function/send_message_raw.dart <==
// ignore_for_file: non_constant_identifier_names, camel_case_extensions

import 'dart:async';
import 'package:galaxeus_lib/extension/regexp.dart';
import 'package:galaxeus_lib/galaxeus_lib.dart' as glx_lib;
import 'package:telegram_client/telegram_client/scheme/json_dart.dart';
import 'package:telegram_client/telegram_client/telegram_client.dart';
import 'package:telegram_client/util/util.dart';

/// method SendMessage
extension SendMessageRawDataOn on TelegramClient {
  /// method SendMessageRaw
  FutureOr<JsonScheme> sendMessageRaw({
    required Map parameters,
    required FutureOr<JsonScheme> Function({
      required Map parameters,
    }) callApiInvoke,
    required TelegramClientData telegramClientData,
  }) async {
    dynamic target_chat_id = TgUtils.parse_all_chat_id(parameters: parameters);
    if (target_chat_id is String &&
        RegExp(r"^((@)[a-z0-9_]+)$", caseSensitive: false)
            .hashData(target_chat_id)) {
      var search_public_chat = await callApiInvoke(
        parameters: {
          "@type": "searchPublicChat",
          "username": (target_chat_id)
              .replaceAll(RegExp(r"@", caseSensitive: false), ""),
        },
      );
      if (search_public_chat["@type"] == "chat") {
        parameters["chat_id"] = search_public_chat["id"];
      }
    }
    Map request_parameters = {
      "@type": "sendMessage",
      "chat_id": parameters["chat_id"],
      "options": <String, dynamic>{
        "@type": "messageSendOptions",
      },
      "input_message_content": <String, dynamic>{},
    };
    List<String> options_parameters = [
      "protect_content",
      "disable_notification",
    ];
    for (var option_parameter in options_parameters) {
      if (parameters[option_parameter] is bool) {
        request_parameters["options"][option_parameter] =
            parameters[option_parameter];
      }
    }
    List<String> input_message_content_parameters = [
      "has_spoiler",
      "disable_web_page_preview",
    ];
    for (var option_parameter in input_message_content_parameters) {
      if (parameters[option_parameter] is bool) {
        request_parameters["input_message_content"][option_parameter] =
            parameters[option_parameter];
      }
    }

    if (parameters.containsKey("message_thread_id")) {
      request_parameters["message_thread_id"] = parameters["message_thread_id"];
    }
    if (parameters["reply_to_message_id"] is int) {
      request_parameters["reply_to"] = {
        "@type": "messageReplyToMessage",
        "chat_id": request_parameters["chat_id"],
        "message_id": request_parameters["message_id"],
      };
    } else if (parameters["reply_to_story_id"] is int) {}
    Map? formatted_text = {
      "@type": "formattedText",
    };

    if (RegExp(r"^(sendMessage)$", caseSensitive: false)
        .hashData(parameters["@type"])) {
      formatted_text["text"] = parameters["text"];
    } else {
      if (parameters["caption"] is String) {
        formatted_text["text"] = parameters["caption"];
        if ((formatted_text["text"] as String).isEmpty) {
          formatted_text = null;
        }
      } else {
        formatted_text = null;
      }
    }

    String parse_mode = () {
      if (parameters["parse_mode"] is String) {
        return parameters["parse_mode"];
      }
      return "";
    }();
    if (formatted_text != null) {
      if (parse_mode == "html") {
        formatted_text = tdlib.td_execute(
          {
            "@type": 'parseTextEntities',
            "parse_mode": {
              "@type": "textParseModeHTML",
            },
            "text": formatted_text["text"],
          },
        );
      } else if (parse_mode == "markdown") {
        formatted_text = tdlib.td_execute(
          {
            "@type": 'parseTextEntities',
            "parse_mode": {
              "@type": "textParseModeMarkdown",
            },
            "text": formatted_text["text"],
          },
        );
      }
    }

    if (RegExp(r"^(sendMessage)$", caseSensitive: false)
        .hashData(parameters["@type"])) {
      request_parameters["input_message_content"]["@type"] = "inputMessageText";

      if (formatted_text != null) {
        request_parameters["input_message_content"]["text"] = formatted_text;
      }
    } else {
      if (formatted_text != null) {
        request_parameters["input_message_content"]["caption"] = formatted_text;
      }
      if (RegExp(r"^(sendAudio)$", caseSensitive: false)
          .hashData(parameters["@type"])) {
        request_parameters["input_message_content"]["@type"] =
            "inputMessageAudio";
        request_parameters["input_message_content"]["photo"] =
            (await TgUtils.typeFile(content: parameters["audio"]));
      }
      if (RegExp(r"^(sendPhoto)$", caseSensitive: false)
          .hashData(parameters["@type"])) {
        request_parameters["input_message_content"]["@type"] =
            "inputMessagePhoto";
        request_parameters["input_message_content"]["photo"] =
            (await TgUtils.typeFile(content: parameters["photo"]));
      }
      if (RegExp(r"^(sendAnimation)$", caseSensitive: false)
          .hashData(parameters["@type"])) {
        request_parameters["input_message_content"]["@type"] =
            "inputMessageAnimation";
        request_parameters["input_message_content"]["animation"] =
            (await TgUtils.typeFile(content: parameters["animation"]));
      }
      if (RegExp(r"^(sendDocument)$", caseSensitive: false)
          .hashData(parameters["@type"])) {
        request_parameters["input_message_content"]["@type"] =
            "inputMessageDocument";
        request_parameters["input_message_content"]["document"] =
            (await TgUtils.typeFile(content: parameters["document"]));
      }
      if (RegExp(r"^(sendSticker)$", caseSensitive: false)
          .hashData(parameters["@type"])) {
        request_parameters["input_message_content"]["@type"] =
            "inputMessageSticker";
        request_parameters["input_message_content"]["sticker"] =
            (await TgUtils.typeFile(content: parameters["sticker"]));
      }
      if (RegExp(r"^(sendVideo)$", caseSensitive: false)
          .hashData(parameters["@type"])) {
        request_parameters["input_message_content"]["@type"] =
            "inputMessageVideo";
        request_parameters["input_message_content"]["video"] =
            (await TgUtils.typeFile(content: parameters["video"]));
      }

      if (RegExp(r"^(sendVoice)$", caseSensitive: false)
          .hashData(parameters["@type"])) {
        request_parameters["input_message_content"]["@type"] =
            "inputMessageVoiceNote";
        request_parameters["input_message_content"]["voice_note"] =
            (await TgUtils.typeFile(content: parameters["voice"]));
      }
    }
    if (parameters["reply_markup"] is Map) {
      Map? reply_markup = TgUtils.replyMarkupTgApiToTdlib(
          replyMarkup: parameters["reply_markup"]);
      if (reply_markup != null) {
        request_parameters["reply_markup"] = reply_markup;
      }
    }

    JsonScheme message_send = await callApiInvoke(
      parameters: request_parameters,
    );
    if (message_send["@type"] == "error") {
      return message_send;
    }
    Map result = {};

    var listen = on(
      event_name: event_update,
      onUpdate: (UpdateTelegramClient updateTelegramClient) async {
        if (updateTelegramClient.telegramClientData.telegramClientType ==
            TelegramClientType.tdlib) {
          if (updateTelegramClient.telegramClientData.tdlib_client_id !=
              telegramClientData.tdlib_client_id) {
            return;
          }
          Map updateOrigin = updateTelegramClient.rawData;
          if (!["updateMessageSendSucceeded", "updateMessageSendFailed"]
              .contains(updateOrigin["@type"])) {
            return;
          }

          if (updateOrigin["message"] is Map &&
              updateOrigin["message"]["chat_id"] == message_send["chat_id"] &&
              updateOrigin["old_message_id"] == message_send["id"]) {
            result = updateOrigin;
          }
        }
      },
      onError: (Object error, StackTrace stackTrace) {},
    );

    while (true) {
      await Future.delayed(Duration(microseconds: 1));
      if (result["@type"] is String) {
        event_emitter.off(listen);

        if (result["@type"] == "error") {
          throw result;
        }
        result.remove("@type");
        if (result["message"] is Map) {
          Map json_message = await message_Message(
              message: result["message"],
              telegramClientData: telegramClientData);

          return JsonScheme(json_message);
        }
      }
    }
  }
}

==> telegram_client-0.5.30.tar.gz: lib/telegram_client/function/send_message_raw.dart <==
// ignore_for_file: non_constant_identifier_names, camel_case_extensions

import 'dart:async';
import 'package:galaxeus_lib/extension/regexp.dart';
import 'package:galaxeus_lib/galaxeus_lib.dart' as glx_lib;
import 'package:telegram_client/telegram_client/scheme/json_dart.dart';
import 'package:telegram_client/telegram_client/telegram_client.dart';
import 'package:telegram_client/util/util.dart';

/// method SendMessage
extension SendMessageRawDataOn on TelegramClient {
  /// method SendMessageRaw
  FutureOr<JsonScheme> sendMessageRaw({
    required Map parameters,
    required FutureOr<JsonScheme> Function({
      required Map parameters,
    }) callApiInvoke,
    required TelegramClientData telegramClientData,
  }) async {
    dynamic target_chat_id = TgUtils.parse_all_chat_id(parameters: parameters);
    if (target_chat_id is String &&
        RegExp(r"^((@)[a-z0-9_]+)$", caseSensitive: false)
            .hashData(target_chat_id)) {
      var search_public_chat = await callApiInvoke(
        parameters: {
          "@type": "searchPublicChat",
          "username": (target_chat_id)
              .replaceAll(RegExp(r"@", caseSensitive: false), ""),
        },
      );
      if (search_public_chat["@type"] == "chat") {
        parameters["chat_id"] = search_public_chat["id"];
      }
    }
    Map request_parameters = {
      "@type": "sendMessage",
      "chat_id": parameters["chat_id"],
      "options": <String, dynamic>{
        "@type": "messageSendOptions",
      },
      "input_message_content": <String, dynamic>{},
    };
    List<String> options_parameters = [
      "protect_content",
      "disable_notification",
    ];
    for (var option_parameter in options_parameters) {
      if (parameters[option_parameter] is bool) {
        request_parameters["options"][option_parameter] =
            parameters[option_parameter];
      }
    }
    List<String> input_message_content_parameters = [
      "has_spoiler",
      "disable_web_page_preview",
    ];
    for (var option_parameter in input_message_content_parameters) {
      if (parameters[option_parameter] is bool) {
        request_parameters["input_message_content"][option_parameter] =
            parameters[option_parameter];
      }
    }

    if (parameters.containsKey("message_thread_id")) {
      request_parameters["message_thread_id"] = parameters["message_thread_id"];
    }
    if (parameters["reply_to_message_id"] is int) {
      request_parameters["reply_to"] = {
        "@type": "messageReplyToMessage",
        "chat_id": request_parameters["chat_id"],
        "message_id": request_parameters["message_id"],
      };
    } else if (parameters["reply_to_story_id"] is int) {}
    Map? formatted_text = {
      "@type": "formattedText",
    };

    if (RegExp(r"^(sendMessage)$", caseSensitive: false)
        .hashData(parameters["@type"])) {
      formatted_text["text"] = parameters["text"];
    } else {
      if (parameters["caption"] is String) {
        formatted_text["text"] = parameters["caption"];
        if ((formatted_text["text"] as String).isEmpty) {
          formatted_text = null;
        }
      } else {
        formatted_text = null;
      }
    }

    String parse_mode = () {
      if (parameters["parse_mode"] is String) {
        return parameters["parse_mode"];
      }
      return "";
    }();
    if (formatted_text != null) {
      if (parse_mode == "html") {
        formatted_text = tdlib.td_execute(
          {
            "@type": 'parseTextEntities',
            "parse_mode": {
              "@type": "textParseModeHTML",
            },
            "text": formatted_text["text"],
          },
        );
      } else if (parse_mode == "markdown") {
        formatted_text = tdlib.td_execute(
          {
            "@type": 'parseTextEntities',
            "parse_mode": {
              "@type": "textParseModeMarkdown",
            },
            "text": formatted_text["text"],
          },
        );
      }
    }

    if (RegExp(r"^(sendMessage)$", caseSensitive: false)
        .hashData(parameters["@type"])) {
      request_parameters["input_message_content"]["@type"] = "inputMessageText";

      if (formatted_text != null) {
        request_parameters["input_message_content"]["text"] = formatted_text;
      }
    } else {
      if (formatted_text != null) {
        request_parameters["input_message_content"]["caption"] = formatted_text;
      }
      if (RegExp(r"^(sendAudio)$", caseSensitive: false)
          .hashData(parameters["@type"])) {
        request_parameters["input_message_content"]["@type"] =
            "inputMessageAudio";
        request_parameters["input_message_content"]["photo"] =
            (await TgUtils.typeFile(
          content: parameters["audio"],
          directory_temp: directory_temp,
        ));
      }
      if (RegExp(r"^(sendPhoto)$", caseSensitive: false)
          .hashData(parameters["@type"])) {
        request_parameters["input_message_content"]["@type"] =
            "inputMessagePhoto";
        request_parameters["input_message_content"]["photo"] =
            (await TgUtils.typeFile(
          content: parameters["photo"],
          directory_temp: directory_temp,
        ));
      }
      if (RegExp(r"^(sendAnimation)$", caseSensitive: false)
          .hashData(parameters["@type"])) {
        request_parameters["input_message_content"]["@type"] =
            "inputMessageAnimation";
        request_parameters["input_message_content"]["animation"] =
            (await TgUtils.typeFile(
          content: parameters["animation"],
          directory_temp: directory_temp,
        ));
      }
      if (RegExp(r"^(sendDocument)$", caseSensitive: false)
          .hashData(parameters["@type"])) {
        request_parameters["input_message_content"]["@type"] =
            "inputMessageDocument";
        request_parameters["input_message_content"]["document"] =
            (await TgUtils.typeFile(
          content: parameters["document"],
          directory_temp: directory_temp,
        ));
      }
      if (RegExp(r"^(sendSticker)$", caseSensitive: false)
          .hashData(parameters["@type"])) {
        request_parameters["input_message_content"]["@type"] =
            "inputMessageSticker";
        request_parameters["input_message_content"]["sticker"] =
            (await TgUtils.typeFile(
          content: parameters["sticker"],
          directory_temp: directory_temp,
        ));
      }
      if (RegExp(r"^(sendVideo)$", caseSensitive: false)
          .hashData(parameters["@type"])) {
        request_parameters["input_message_content"]["@type"] =
            "inputMessageVideo";
        request_parameters["input_message_content"]["video"] =
            (await TgUtils.typeFile(
          content: parameters["video"],
          directory_temp: directory_temp,
        ));
      }

      if (RegExp(r"^(sendVoice)$", caseSensitive: false)
          .hashData(parameters["@type"])) {
        request_parameters["input_message_content"]["@type"] =
            "inputMessageVoiceNote";
        request_parameters["input_message_content"]["voice_note"] =
            (await TgUtils.typeFile(
          content: parameters["voice"],
          directory_temp: directory_temp,
        ));
      }
    }
    if (parameters["reply_markup"] is Map) {
      Map? reply_markup = TgUtils.replyMarkupTgApiToTdlib(
          replyMarkup: parameters["reply_markup"]);
      if (reply_markup != null) {
        request_parameters["reply_markup"] = reply_markup;
      }
    }

    JsonScheme message_send = await callApiInvoke(
      parameters: request_parameters,
    );
    if (message_send["@type"] == "error") {
      return message_send;
    }
    Map result = {};

    var listen = on(
      event_name: event_update,
      onUpdate: (UpdateTelegramClient updateTelegramClient) async {
        if (updateTelegramClient.telegramClientData.telegramClientType ==
            TelegramClientType.tdlib) {
          if (updateTelegramClient.telegramClientData.tdlib_client_id !=
              telegramClientData.tdlib_client_id) {
            return;
          }
          Map updateOrigin = updateTelegramClient.rawData;
          if (!["updateMessageSendSucceeded", "updateMessageSendFailed"]
              .contains(updateOrigin["@type"])) {
            return;
          }

          if (updateOrigin["message"] is Map &&
              updateOrigin["message"]["chat_id"] == message_send["chat_id"] &&
              updateOrigin["old_message_id"] == message_send["id"]) {
            result = updateOrigin;
          }
        }
      },
      onError: (Object error, StackTrace stackTrace) {},
    );

    while (true) {
      await Future.delayed(Duration(microseconds: 1));
      if (result["@type"] is String) {
        event_emitter.off(listen);

        if (result["@type"] == "error") {
          throw result;
        }
        result.remove("@type");
        if (result["message"] is Map) {
          Map json_message = await message_Message(
              message: result["message"],
              telegramClientData: telegramClientData);

          return JsonScheme(json_message);
        }
      }
    }
  }
}
